// Common description constant
const commonDescription =
  "UK Manufactured cartridges to the highest standards which are high speed balanced. These cartridges are the perfect replacements for old and worn cartridges, without having to spend money on brand new turbos or taking chances on used turbos. If the turbocharger is internally damaged, or if the turbocharger seals are leaking oil this will resolve the issue.\n\n Please diagnose for boost leaks, failed wastegates and source of turbo failure to ensure a successful repair.";

// Example data object for model details
const modelDetails = {
  bmw1: {
    name: "N54 Engine Powered Models",
    subtitle: "",
    partnumberLeft: "OEM Part Number : Front 11657649289",
    partnumberRight: "OEM Part Number : Rear 11657649291",
    usdLeftPrice: "$650.00 USD",
    cadLeftPrice: "$850.00 CAD",
    usdRightPrice: "$650.00 USD",
    cadRightPrice: "$1000.00 CAD",
    usdLeftOriginalPrice: "$850.00 USD",
    usdRightOriginalPrice: "$850.00 USD",
    cadLeftOriginalPrice: "$1000.00 CAD",
    cadRightOriginalPrice: "$1000.00 CAD",
    description: commonDescription,
    mainCategory: "BMW",
    subCategory: "N54",
    rating: 5,
    isNew: false,
  },
  bmw2: {
    name: "N55 Engine Powered models (Except N55 M2)",
    subtitle: "With Pneumatic Wastegate",
    partnumberLeft: "OEM Part Number : 11657636424",
    partnumberRight: "",
    usdLeftPrice: "$650.00 USD",
    cadLeftPrice: "$850.00 CAD",
    usdRightPrice: "",
    cadRightPrice: "",
    usdLeftOriginalPrice: "$850.00 USD",
    usdRightOriginalPrice: "",
    cadLeftOriginalPrice: "$1000.00 CAD",
    cadRightOriginalPrice: "",
    description: commonDescription,
    mainCategory: "BMW",
    subCategory: "N55",
    rating: 5,
    isNew: false,
  },
  bmw3: {
    name: "N20 Engine Powered Models",
    subtitle: "With Electronic Wastegate",
    partnumberLeft: "OEM Part Number : 11657642469",
    partnumberRight: "",
    usdLeftPrice: "$650.00 USD",
    cadLeftPrice: "$850.00 CAD",
    usdRightPrice: "",
    cadRightPrice: "",
    usdLeftOriginalPrice: "$850.00 USD",
    usdRightOriginalPrice: "",
    cadLeftOriginalPrice: "$1000.00 CAD",
    cadRightOriginalPrice: "",
    description: commonDescription,
    mainCategory: "BMW",
    subCategory: "N55",
    rating: 5,
    isNew: false,
  },
  bmw4: {
    name: "B48 Engine Powered Models",
    subtitle: "",
    partnumberLeft: "OEM Part Number : 11658662074",
    partnumberRight: "",
    usdLeftPrice: "$650.00 USD",
    cadLeftPrice: "$850.00 CAD",
    usdRightPrice: "",
    cadRightPrice: "",
    usdLeftOriginalPrice: "$850.00 USD",
    usdRightOriginalPrice: "",
    cadLeftOriginalPrice: "$1000.00 CAD",
    cadRightOriginalPrice: "",
    description: commonDescription,
    mainCategory: "BMW",
    subCategory: "N55",
    rating: 5,
    isNew: false,
  },
  bmw5: {
    name: "S55 Engine Powered Models",
    subtitle: "",
    partnumberLeft: "OEM Part Number: Front 11657849650",
    partnumberRight: "OEM Part Number: Rear 11657849651",
    usdLeftPrice: "$650.00 USD",
    cadLeftPrice: "$1000.00 CAD",
    usdRightPrice: "$650.00 USD",
    cadRightPrice: "$1000.00 CAD",
    usdLeftOriginalPrice: "$850.00 USD",
    usdRightOriginalPrice: "$850.00 USD",
    cadLeftOriginalPrice: "$1200.00 CAD",
    cadRightOriginalPrice: "$1200.00 CAD",
    description: commonDescription,
    mainCategory: "BMW",
    subCategory: "S55",
    rating: 5,
    isNew: false,
  },
  bmw6: {
    name: "S58 Engine Powered Models",
    subtitle: "",
    partnumberLeft: "OEM Part Number : Front 11658469097",
    partnumberRight: "OEM Part Number : Rear 11658469098",
    usdLeftPrice: "$650.00 USD",
    cadLeftPrice: "$1000.00 CAD",
    usdRightPrice: "$650.00 USD",
    cadRightPrice: "$1000.00 CAD",
    usdLeftOriginalPrice: "$850.00 USD",
    usdRightOriginalPrice: "$850.00 USD",
    cadLeftOriginalPrice: "$1200.00 CAD",
    cadRightOriginalPrice: "$1200.00 CAD",
    description: commonDescription,
    mainCategory: "BMW",
    subCategory: "S55",
    rating: 5,
    isNew: false,
  },
};

// Function to render product details
function renderProductDetails(productDiv, modelData) {
  // Find elements for name, prices, and part numbers within each product div
  const modelNameElement = productDiv.querySelector("#model-name");
  const modelLeftPriceElement = productDiv.querySelector("#model-left-price");
  const modelRightPriceElement = productDiv.querySelector("#model-right-price");
  const partNumberLeftElement = productDiv.querySelector("#part-number-left");
  const partNumberRightElement = productDiv.querySelector("#part-number-right");

  // Update name and prices in the div
  modelNameElement.textContent = modelData.name;

  // Initially render the price based on the default selected currency (USD)
  const selectedCurrency = document.getElementById("currencySelect").value;
  if (selectedCurrency === "USD") {
    modelLeftPriceElement.textContent = modelData.usdLeftPrice;
    modelRightPriceElement.textContent = modelData.usdRightPrice;
  } else if (selectedCurrency === "CAD") {
    modelLeftPriceElement.textContent = modelData.cadLeftPrice;
    modelRightPriceElement.textContent = modelData.cadRightPrice;
  }

  // Render part numbers dynamically
  partNumberLeftElement.textContent = modelData.partnumberLeft;
  partNumberRightElement.textContent = modelData.partnumberRight;

  // New: Render mainCategory, subCategory, description, and rating
  const mainCategoryElement = productDiv.querySelector("#model-main-category");
  const subCategoryElement = productDiv.querySelector("#model-sub-category");
  const descriptionElement = productDiv.querySelector("#model-description");
  const ratingElement = productDiv.querySelector("#model-rating");

  if (mainCategoryElement)
    mainCategoryElement.textContent = `Category: ${modelData.mainCategory}`;
  if (subCategoryElement)
    subCategoryElement.textContent = `Subcategory: ${modelData.subCategory}`;
  if (descriptionElement)
    descriptionElement.textContent = modelData.description;
  if (ratingElement)
    ratingElement.textContent = `Rating: ${modelData.rating} stars`;
  // New: Conditionally render the right-oem section based on usdRightPrice
  const rightOemDiv = productDiv.querySelector(".right-oem");
  if (modelData.usdRightPrice && modelData.usdRightPrice.trim() !== "") {
    // If usdRightPrice exists and is not empty, display the div
    rightOemDiv.style.display = "block";
  } else {
    // Otherwise, hide it
    rightOemDiv.style.display = "none";
  }
}

// Function to render all products
function renderAllProducts() {
  const productContainer = document.getElementById("product-container");

  // Loop through modelDetails to create product divs
  Object.keys(modelDetails).forEach((modelKey, index) => {
    const model = modelDetails[modelKey];

    // Create the product div
    const productDiv = document.createElement("div");
    productDiv.classList.add("col-lg-4", "col-md-6", "col-sm-6", "orangeboxs");
    productDiv.id = `div${index + 1}`;

    // Add the onClick function to redirect
    productDiv.onclick = () => redirectToModelPage(modelKey);
    const badgeContent = model.isNew
      ? '<li><span class="badge badge-primary">REPEATED "NAME" PRODUCT</span></li>'
      : '<li><span class="badge badge-danger">SALE</span></li>';

    // Your existing function to handle the redirection

    // Add inner HTML structure
    productDiv.innerHTML = `
      <div class="product_item">
        <ul class="badge_group unordered_list">
           ${badgeContent}
        </ul>
        <a class="item_image">
          <img src="assets/images/products/product_img_1.png" alt="ProMotors - Product Image"/>
        </a>
        <div class="item_content">
          <a href="" class="whitecol">${model.mainCategory}</a>
          <h3 class="item_title">
            <a id="model-name">${model.name}</a>
          </h3>
          <h6><a class="orangecol">${model.subtitle}</a>
                        </h6>
          <div class="item_footer">
            <div class="item_price">
              <span id="model-left-price" class="sale_price">${model.usdLeftPrice}</span>
            </div>
            <a class="btn-link">
              <span class="btn_icon"><i class="fa-regular fa-angle-right"></i></span>
              <span class="btn_text">
                <small>Add To Cart</small>
                <small>Add To Cart</small>
              </span>
            </a>
          </div>
          <a class="item_brand">
            <span id="part-number-left">${model.partnumberLeft}</span>
          </a>
          <div class="item_footer">
            <div class="item_price">
              <span id="model-right-price" class="sale_price">${model.usdRightPrice}</span>
            </div>
            <span class="right-oem">
            <a class="btn-link">
              <span class="btn_icon"><i class="fa-regular fa-angle-right"></i></span>
              <span class="btn_text">
                <small>Add To Cart</small>
                <small>Add To Cart</small>
              </span>
            </a>
            </span>
          </div>
          <a class="item_brand">
            <span id="part-number-right">${model.partnumberRight}</span>
          </a>
        </div>
        <ul class="cart_btns_group unordered_list_block">
          <li><a href="bmw.html"><i class="fa-light fa-heart"></i></a></li>
          <li><a href="bmw.html"><i class="fa-light fa-eye"></i></a></li>
          <li><a href="bmw.html"><i class="fa-light fa-code-compare"></i></a></li>
        </ul>
      </div>
    `;

    // Render product details
    renderProductDetails(productDiv, model);

    // Append the product div to the container
    productContainer.appendChild(productDiv);
  });
}

// Function to update the prices based on selected currency
function updatePricesBasedOnCurrency() {
  const selectedCurrency = document.getElementById("currencySelect").value;

  document.querySelectorAll(".product_item").forEach((productDiv) => {
    const modelId = `bmw${productDiv.parentElement.id.replace("div", "")}`;
    const modelData = modelDetails[modelId];

    // Check if modelData exists for this ID
    if (modelData) {
      const modelLeftPriceElement =
        productDiv.querySelector("#model-left-price");
      const modelRightPriceElement =
        productDiv.querySelector("#model-right-price");

      // Update prices based on selected currency
      if (selectedCurrency === "USD") {
        modelLeftPriceElement.textContent = modelData.usdLeftPrice;
        modelRightPriceElement.textContent = modelData.usdRightPrice;
      } else if (selectedCurrency === "CAD") {
        modelLeftPriceElement.textContent = modelData.cadLeftPrice;
        modelRightPriceElement.textContent = modelData.cadRightPrice;
      }
    }
  });
}

// Event listener for when the dropdown selection changes
document
  .getElementById("currencySelect")
  .addEventListener("change", updatePricesBasedOnCurrency);

// Call renderAllProducts when the page loads
document.addEventListener("DOMContentLoaded", renderAllProducts);

// Function to handle redirection with the product key in the URL
function redirectToModelPage(modelKey) {
  window.location.href = `bmw-dynamic-page.html?product=${modelKey}`;
}
